@@ -24,7 +24,7 @@
 #include "incidenceeditor-ng.h"
 
 #include <KCalendarCore/FreeBusy>
-
+#include <KContacts/Addressee>
 namespace Ui {
 class EventOrTodoDesktop;
 }
@@ -110,6 +110,8 @@ private Q_SLOTS:
 private:
     void updateGroupExpand();
 
+    void insertAddresses(const KContacts::Addressee::List &list);
+
     void changeStatusForMe(KCalendarCore::Attendee::PartStat);
 
     /** Returns if I was the organizer of the loaded event */
