@@ -33,7 +33,7 @@ namespace CalendarSupport {
 class FreeBusyItemModel;
 }
 
-class KComboBox;
+class QComboBox;
 class QTreeView;
 
 namespace IncidenceEditorNG {
@@ -44,8 +44,7 @@ class VisualFreeBusyWidget : public QWidget
 {
     Q_OBJECT
 public:
-    explicit VisualFreeBusyWidget(CalendarSupport::FreeBusyItemModel *model, int spacing = 8,
-                                  QWidget *parent = nullptr);
+    explicit VisualFreeBusyWidget(CalendarSupport::FreeBusyItemModel *model, int spacing = 8, QWidget *parent = nullptr);
     ~VisualFreeBusyWidget();
 
 public Q_SLOTS:
@@ -70,7 +69,7 @@ private:
     RowController *mRowController = nullptr;
     KGantt::DateTimeGrid *mGanttGrid = nullptr;
 
-    KComboBox *mScaleCombo = nullptr;
+    QComboBox *mScaleCombo = nullptr;
     FreeBusyGanttProxyModel *mModel = nullptr;
 
     QDateTime mDtStart, mDtEnd;
